"""IPython extension that makes multiplication implied between identifiers and
numbers

NOTE: VERY EXPERIMENTAL IT MAY BREAK SOME PYTHON CODE"""

from .inferred_multi import load_ipython_extension, unload_ipython_extension

